@@ -25,14 +25,15 @@
 #' # and that raster and rgdal are also installed.
 #' # Note this isn't strictly neccessary, as executing the function will
 #' # force a search for a valid GDAL install.
+#' outdir <- tempdir()
 #' gdal_setInstallation()
 #' valid_install <- !is.null(getOption("gdalUtils_gdalPath"))
 #' if(require(raster) && require(rgdal) && valid_install)
 #' {
 #' layer1 <- system.file("external/tahoe_lidar_bareearth.tif", package="gdalUtils")
 #' layer2 <- system.file("external/tahoe_lidar_highesthit.tif", package="gdalUtils")
-#' mosaic_rasters(gdalfile=c(layer1,layer2),dst_dataset="test_mosaic.envi",separate=TRUE,of="ENVI",
-#' 		verbose=TRUE)
+#' mosaic_rasters(gdalfile=c(layer1,layer2),dst_dataset=file.path(outdir,"test_mosaic.envi"),
+#' 		separate=TRUE,of="ENVI",verbose=TRUE)
 #' gdalinfo("test_mosaic.envi")
 #' }
 #' @import rgdal
@@ -85,7 +86,7 @@ mosaic_rasters <- function(gdalfile,dst_dataset,output.vrt=NULL,output_Raster=FA
 	
 	# browser()
 	
-	if(is.numeric(gdalwarp_index))
+	if(is.numeric(gdalwarp_index) && (is.null(gdalwarp_params$t_srs) || is.na(gdalwarp_params$t_srs)))
 	{
 		gdalwarp_params$t_srs <- gdalfile_proj4s[gdalwarp_index]
 		
